@@ -11,9 +11,9 @@
 * published by the Free Software Foundation; either version 2 of
 * the License or (at your option) version 3 or any later version
 * accepted by the membership of KDE e.V. (or its successor approved
-* by the membership of KDE e.V.), which shall act as a proxy 
+* by the membership of KDE e.V.), which shall act as a proxy
 * defined in Section 14 of version 3 of the license.
-* 
+*
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
@@ -52,9 +52,13 @@
 FindBar::FindBar(QWidget *parent)
         : QWidget(parent)
         , m_lineEdit(new KLineEdit(this))
-        , m_matchCase(new QCheckBox(i18n("&Match case"), this))
         , m_hideTimer(new QTimer(this))
+        , m_matchCase(new QCheckBox(i18n("&Match case"), this))
+        , m_highlightAll(new QCheckBox(i18n("&Highlight all"), this))
 {
+    // mainwindow pointer
+    MainWindow *window = qobject_cast<MainWindow *>(parent);
+
     QHBoxLayout *layout = new QHBoxLayout;
 
     // cosmetic
@@ -65,19 +69,17 @@ FindBar::FindBar(QWidget *parent)
     hideButton->setAutoRaise(true);
     hideButton->setIcon(KIcon("dialog-close"));
     connect(hideButton, SIGNAL(clicked()), this, SLOT(hide()));
+    connect(hideButton, SIGNAL(clicked()), window, SLOT(highlightAll()));
     layout->addWidget(hideButton);
     layout->setAlignment(hideButton, Qt::AlignLeft | Qt::AlignTop);
 
-    // hide timer 
+    // hide timer
     connect(m_hideTimer, SIGNAL(timeout()), this, SLOT(hide()));
 
     // label
     QLabel *label = new QLabel(i18n("Find:"));
     layout->addWidget(label);
 
-    // mainwindow pointer
-    MainWindow *window = qobject_cast<MainWindow *>(parent);
-    
     // lineEdit, focusProxy
     setFocusProxy(m_lineEdit);
     m_lineEdit->setMaximumWidth(250);
@@ -99,11 +101,17 @@ FindBar::FindBar(QWidget *parent)
     connect(m_matchCase, SIGNAL(toggled(bool)), window, SLOT(matchCaseUpdate()));
     layout->addWidget(m_matchCase);
 
+    // Hightlight All. On by default
+    m_highlightAll->setCheckState(Qt::Checked);
+    m_highlightAll->setTristate(false);
+    connect(m_highlightAll, SIGNAL(toggled(bool)), window, SLOT(highlightAll()));
+    layout->addWidget(m_highlightAll);
+
     // stretching widget on the left
     layout->addStretch();
 
     setLayout(layout);
-    
+
     // we start off hidden
     hide();
 }
@@ -111,12 +119,10 @@ FindBar::FindBar(QWidget *parent)
 
 FindBar::~FindBar()
 {
-}
-
-
-KLineEdit *FindBar::lineEdit() const
-{
-    return m_lineEdit;
+    delete m_lineEdit;
+    delete m_hideTimer;
+    delete m_matchCase;
+    delete m_highlightAll;
 }
 
 
@@ -126,18 +132,23 @@ bool FindBar::matchCase() const
 }
 
 
+bool FindBar::highlightAllState() const
+{
+    return m_highlightAll->isChecked();
+}
+
+
 void FindBar::show()
 {
     // show findbar if not visible
-    if (isVisible())
-        return;
-    
-    QWidget::show();
+    if (isHidden())
+    {
+        QWidget::show();
+        emit searchString(m_lineEdit->text());
+    }
+
     m_hideTimer->start(60000);
-    
-    // emit a new find signal with the current text
-    emit(searchString(m_lineEdit->text()));
-    
+
     // set focus to findbar if user select showFindBar shortcut
     m_lineEdit->setFocus();
     m_lineEdit->selectAll();
@@ -152,7 +163,7 @@ void FindBar::notifyMatch(bool match)
     {
         p.setColor(QPalette::Base, QColor(KApplication::palette().color(QPalette::Active, QPalette::Base)));
     }
-    else 
+    else
     {
         if (match)
         {
