@@ -13,9 +13,9 @@
 * published by the Free Software Foundation; either version 2 of
 * the License or (at your option) version 3 or any later version
 * accepted by the membership of KDE e.V. (or its successor approved
-* by the membership of KDE e.V.), which shall act as a proxy 
+* by the membership of KDE e.V.), which shall act as a proxy
 * defined in Section 14 of version 3 of the license.
-* 
+*
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
@@ -35,7 +35,6 @@
 #include "rekonq.h"
 
 // Local Includes
-#include "webtab.h"
 #include "tabbar.h"
 #include "urlbar.h"
 #include "sessionmanager.h"
@@ -46,7 +45,6 @@
 #include <KShortcut>
 #include <KStandardShortcut>
 #include <KMessageBox>
-#include <KDebug>
 #include <KStandardDirs>
 #include <KPassivePopup>
 #include <KLocalizedString>
@@ -63,11 +61,11 @@
 
 
 MainView::MainView(MainWindow *parent)
-    : KTabWidget(parent)
-    , m_urlBar(new UrlBar(this))
-    , m_addTabButton(0)
-    , m_currentTabIndex(0)
-    , m_parentWindow(parent)
+        : KTabWidget(parent)
+        , _widgetBar(new StackedUrlBar(this))
+        , m_addTabButton(0)
+        , m_currentTabIndex(0)
+        , m_parentWindow(parent)
 {
     // setting tabbar
     TabBar *tabBar = new TabBar(this);
@@ -76,40 +74,56 @@ MainView::MainView(MainWindow *parent)
 
     // set mouse tracking for tab previews
     setMouseTracking(true);
-     
+
     // loading pixmap path
     m_loadingGitPath = KStandardDirs::locate("appdata" , "pics/loading.mng");
 
     // connecting tabbar signals
-    connect(tabBar, SIGNAL(closeTab(int)),          this,   SLOT(closeTab(int)) );
-    connect(tabBar, SIGNAL(mouseMiddleClick(int)),  this,   SLOT(closeTab(int)) );
-    connect(tabBar, SIGNAL(newTabRequest()),        this,   SLOT(newTab())      );
-    
-    connect(tabBar, SIGNAL(cloneTab(int)),          this,   SLOT(cloneTab(int)) );
-    connect(tabBar, SIGNAL(closeOtherTabs(int)),    this,   SLOT(closeOtherTabs(int))   );
-    connect(tabBar, SIGNAL(reloadTab(int)),         this,   SLOT(reloadTab(int))    );
-    connect(tabBar, SIGNAL(reloadAllTabs()),        this,   SLOT(reloadAllTabs())   );
-    connect(tabBar, SIGNAL(detachTab(int)),         this,   SLOT(detachTab(int))    );
-    
-    connect(tabBar, SIGNAL(tabCloseRequested(int)), this,   SLOT(closeTab(int)) );
-    
+    connect(tabBar, SIGNAL(closeTab(int)),          this,   SLOT(closeTab(int)));
+    connect(tabBar, SIGNAL(mouseMiddleClick(int)),  this,   SLOT(closeTab(int)));
+    connect(tabBar, SIGNAL(newTabRequest()),        this,   SLOT(newTab()));
+
+    connect(tabBar, SIGNAL(cloneTab(int)),          this,   SLOT(cloneTab(int)));
+    connect(tabBar, SIGNAL(closeOtherTabs(int)),    this,   SLOT(closeOtherTabs(int)));
+    connect(tabBar, SIGNAL(reloadTab(int)),         this,   SLOT(reloadTab(int)));
+    connect(tabBar, SIGNAL(reloadAllTabs()),        this,   SLOT(reloadAllTabs()));
+    connect(tabBar, SIGNAL(detachTab(int)),         this,   SLOT(detachTab(int)));
+
+    connect(tabBar, SIGNAL(tabCloseRequested(int)), this,   SLOT(closeTab(int)));
+    connect(tabBar, SIGNAL(tabMoved(int, int)),     _widgetBar, SLOT(moveBar(int, int)));
+
     // current page index changing
     connect(this, SIGNAL(currentChanged(int)), this, SLOT(currentChanged(int)));
-    
+
     QTimer::singleShot(0, this, SLOT(postLaunch()));
 }
 
 
 MainView::~MainView()
 {
+    delete _widgetBar;
+    delete m_addTabButton;
 }
 
 
 void MainView::postLaunch()
 {
-    // Session Manager
-    connect (this, SIGNAL(tabsChanged()), Application::sessionManager(), SLOT(saveSession()));
+    QStringList list = Application::sessionManager()->closedSites();
+    foreach(const QString &line, list)
+    {
+        if(line.startsWith( QL1S("about") ))
+            break;
+        QString title = line;
+        QString url = title;
+        HistoryItem item(url, QDateTime(), title);
+        m_recentlyClosedTabs.removeAll(item);
+        m_recentlyClosedTabs.prepend(item);
+    }
     
+    // Session Manager
+    connect(this, SIGNAL(tabsChanged()), Application::sessionManager(), SLOT(saveSession()));
+    connect(this, SIGNAL(currentChanged(int)), Application::sessionManager(), SLOT(saveSession()));
+
     m_addTabButton->setDefaultAction(m_parentWindow->actionByName("new_tab"));
 
     m_addTabButton->setAutoRaise(true);
@@ -119,8 +133,6 @@ void MainView::postLaunch()
 
 void MainView::updateTabButtonPosition()
 {
-    kDebug() << "updating new tab button position..";
-    
     static bool ButtonInCorner = false;
 
     int tabWidgetWidth = frameSize().width();
@@ -128,14 +140,14 @@ void MainView::updateTabButtonPosition()
 
     if (tabBarWidth + m_addTabButton->width() > tabWidgetWidth)
     {
-        if(ButtonInCorner)
+        if (ButtonInCorner)
             return;
         setCornerWidget(m_addTabButton);
         ButtonInCorner = true;
     }
     else
     {
-        if(ButtonInCorner)
+        if (ButtonInCorner)
         {
             setCornerWidget(0);
             m_addTabButton->show();
@@ -143,36 +155,26 @@ void MainView::updateTabButtonPosition()
         }
 
         // detecting X position
-        int newPosX = tabBarWidth;      
+        int newPosX = tabBarWidth;
         int tabWidthHint = tabBar()->tabSizeHint(0).width();
-        if (tabWidthHint < sizeHint().width()/4)
+        if (tabWidthHint < sizeHint().width() / 4)
             newPosX = tabWidgetWidth - m_addTabButton->width();
 
-        // Y position is fixed
-        // Here I noticed with some emphiric valutations ( :D )
-        // that 2 look better than 0, just that..
-
-        m_addTabButton->move(newPosX, 2);
+        m_addTabButton->move(newPosX, 0);
     }
 }
 
 
-QToolButton *MainView::addTabButton() const
-{
-    return m_addTabButton;
-}
-
-
 TabBar *MainView::tabBar() const
 {
-    TabBar *tabBar = qobject_cast<TabBar *>( KTabWidget::tabBar() );
-    return tabBar; 
+    TabBar *tabBar = qobject_cast<TabBar *>(KTabWidget::tabBar());
+    return tabBar;
 }
 
 
-UrlBar *MainView::urlBar() const 
-{ 
-    return m_urlBar; 
+UrlBar *MainView::urlBar() const
+{
+    return _widgetBar->urlBar(m_currentTabIndex);
 }
 
 
@@ -184,7 +186,7 @@ WebTab *MainView::currentWebTab() const
 
 void MainView::updateTabBar()
 {
-    if( ReKonfig::alwaysShowTabBar() )
+    if (ReKonfig::alwaysShowTabBar())
     {
         if (!isTabBarHidden())
         {
@@ -198,14 +200,14 @@ void MainView::updateTabBar()
         return;
     }
 
-    if( tabBar()->count() == 1 )
+    if (tabBar()->count() == 1)
     {
         tabBar()->hide();
         m_addTabButton->hide();
     }
-    else if( !isTabBarHidden() )
+    else if (!isTabBarHidden())
     {
-        if ( tabBar()->isHidden() )
+        if (tabBar()->isHidden())
         {
             tabBar()->show();
             m_addTabButton->show();
@@ -238,17 +240,6 @@ void MainView::webStop()
 }
 
 
-void MainView::clear()
-{
-    // FIXME (the programmer, not the code)
-    // What exactly do we need to clear here?
-    m_urlBar->clearHistory();
-    m_urlBar->clear();
-
-    m_recentlyClosedTabs.clear();
-}
-
-
 // When index is -1 index chooses the current tab
 void MainView::reloadTab(int index)
 {
@@ -271,17 +262,12 @@ void MainView::currentChanged(int index)
 
     // retrieve the old webview (that where we move from)
     WebTab *oldTab = this->webTab(m_currentTabIndex);
-    
+
     // set current index
     m_currentTabIndex = index;
 
     if (oldTab)
-    {        
-        // disconnecting webview from urlbar
-        disconnect(oldTab->view(), SIGNAL(loadProgress(int)), urlBar(), SLOT(updateProgress(int)));
-        disconnect(oldTab->view(), SIGNAL(loadFinished(bool)), urlBar(), SLOT(loadFinished(bool)));
-        disconnect(oldTab->view(), SIGNAL(urlChanged(const QUrl &)), urlBar(), SLOT(setUrl(const QUrl &)));
-    
+    {
         // disconnecting webpage from mainview
         disconnect(oldTab->page(), SIGNAL(statusBarMessage(const QString&)),
                    this, SIGNAL(showStatusBarMessage(const QString&)));
@@ -289,42 +275,40 @@ void MainView::currentChanged(int index)
                    this, SIGNAL(linkHovered(const QString&)));
     }
 
-    // connecting webview with urlbar
-    connect(tab->view(), SIGNAL(loadProgress(int)), urlBar(), SLOT(updateProgress(int)));
-    connect(tab->view(), SIGNAL(loadFinished(bool)), urlBar(), SLOT(loadFinished(bool)));
-    connect(tab->view(), SIGNAL(urlChanged(const QUrl &)), urlBar(), SLOT(setUrl(const QUrl &)));
-    
-    connect(tab->page(), SIGNAL(statusBarMessage(const QString&)), 
+    connect(tab->page(), SIGNAL(statusBarMessage(const QString&)),
             this, SIGNAL(showStatusBarMessage(const QString&)));
-    connect(tab->page(), SIGNAL(linkHovered(const QString&, const QString&, const QString&)), 
+    connect(tab->page(), SIGNAL(linkHovered(const QString&, const QString&, const QString&)),
             this, SIGNAL(linkHovered(const QString&)));
 
-    emit setCurrentTitle(tab->view()->title());
-    urlBar()->setUrl(tab->view()->url());
-    urlBar()->setProgress(tab->progress());
+    emit currentTitle(tab->view()->title());
+    _widgetBar->setCurrentIndex(index);
 
     // clean up "status bar"
-    emit showStatusBarMessage( QString() );
+    emit showStatusBarMessage(QString());
 
     // notify UI to eventually switch stop/reload button
-    if(urlBar()->isLoading())
-        emit browserTabLoading(true);
-    else
+    int progr = tab->progress();
+    if (progr == 0)
         emit browserTabLoading(false);
-    
+    else
+        emit browserTabLoading(true);
+
     // update zoom slider
-    if(!Application::instance()->mainWindowList().isEmpty())
+    if (!Application::instance()->mainWindowList().isEmpty())
         Application::instance()->mainWindow()->setZoomSliderFactor(tab->view()->zoomFactor());
 
     // set focus to the current webview
-    tab->view()->setFocus();
+    if (tab->url().scheme() == QL1S("about"))
+        _widgetBar->currentWidget()->setFocus();
+    else
+        tab->view()->setFocus();
 }
 
 
 WebTab *MainView::webTab(int index) const
 {
-    WebTab *tab = qobject_cast<WebTab *>( this->widget(index) );
-    if(tab)
+    WebTab *tab = qobject_cast<WebTab *>(this->widget(index));
+    if (tab)
     {
         return tab;
     }
@@ -334,9 +318,10 @@ WebTab *MainView::webTab(int index) const
 }
 
 
-WebTab *MainView::newWebTab(bool focused, bool nearParent)
+WebTab *MainView::newWebTab(bool focused)
 {
     WebTab* tab = new WebTab(this);
+    UrlBar *bar = new UrlBar(tab);
 
     // connecting webview with mainview
     connect(tab->view(), SIGNAL(loadStarted()), this, SLOT(webViewLoadStarted()));
@@ -344,25 +329,31 @@ WebTab *MainView::newWebTab(bool focused, bool nearParent)
     connect(tab->view(), SIGNAL(iconChanged()), this, SLOT(webViewIconChanged()));
     connect(tab->view(), SIGNAL(titleChanged(const QString &)), this, SLOT(webViewTitleChanged(const QString &)));
     connect(tab->view(), SIGNAL(urlChanged(const QUrl &)), this, SLOT(webViewUrlChanged(const QUrl &)));
+    connect(tab->view(), SIGNAL(zoomChanged(qreal)), m_parentWindow, SLOT(setZoomSliderFactor(qreal)));
 
     // connecting webPage signals with mainview
     connect(tab->view()->page(), SIGNAL(windowCloseRequested()), this, SLOT(windowCloseRequested()));
     connect(tab->view()->page(), SIGNAL(printRequested(QWebFrame *)), this, SIGNAL(printRequested(QWebFrame *)));
-    
-    if (nearParent)
-        insertTab(currentIndex() + 1, tab, i18n("(Untitled)"));
-    else
-        addTab(tab, i18n("(Untitled)"));
 
+    if ( ReKonfig::openTabsNearCurrent() )
+    {
+        insertTab(currentIndex() + 1, tab, i18n("(Untitled)"));
+        _widgetBar->insertWidget(currentIndex() + 1, bar);
+    }
+    else
+    {
+        addTab(tab, i18n("(Untitled)"));
+        _widgetBar->addWidget(bar);
+    }
     updateTabBar();
-    
+
     if (focused)
     {
         setCurrentWidget(tab);
     }
 
     emit tabsChanged();
-    
+
     return tab;
 }
 
@@ -371,16 +362,16 @@ void MainView::newTab()
 {
     WebView *w = newWebTab()->view();
 
-    switch(ReKonfig::newTabsBehaviour())
+    switch (ReKonfig::newTabsBehaviour())
     {
     case 0: // new tab page
-        w->load( KUrl("about:home") );
+        w->load(KUrl("about:home"));
         break;
     case 1: // blank page
-        urlBar()->setUrl(KUrl(""));
+        urlBar()->clear();
         break;
     case 2: // homepage
-        w->load( KUrl(ReKonfig::homePage()) );
+        w->load(KUrl(ReKonfig::homePage()));
         break;
     default:
         break;
@@ -400,9 +391,9 @@ void MainView::reloadAllTabs()
 
 void MainView::windowCloseRequested()
 {
-    WebPage *page = qobject_cast<WebPage *>( sender() );
-    WebView *view = qobject_cast<WebView *>( page->view() );
-    int index = indexOf( view->parentWidget() );
+    WebPage *page = qobject_cast<WebPage *>(sender());
+    WebView *view = qobject_cast<WebView *>(page->view());
+    int index = indexOf(view->parentWidget());
 
     if (index >= 0)
     {
@@ -422,9 +413,11 @@ void MainView::windowCloseRequested()
 
 void MainView::closeOtherTabs(int index)
 {
-    if (-1 == index)
+    if (index < 0)
+        index = currentIndex();
+    if (index < 0 || index >= count())
         return;
-
+    
     for (int i = count() - 1; i > index; --i)
     {
         closeTab(i);
@@ -439,17 +432,16 @@ void MainView::closeOtherTabs(int index)
 }
 
 
-// When index is -1 index chooses the current tab
 void MainView::cloneTab(int index)
 {
     if (index < 0)
         index = currentIndex();
     if (index < 0 || index >= count())
         return;
-    
+
     WebTab *tab = newWebTab();
     KUrl url = webTab(index)->url();
-    
+
     // workaround against bug in webkit:
     // only set url if it is not empty
     // otherwise the current working directory will be used
@@ -461,26 +453,29 @@ void MainView::cloneTab(int index)
 
 
 // When index is -1 index chooses the current tab
-void MainView::closeTab(int index)
+void MainView::closeTab(int index, bool del)
 {
     // open default homePage if just one tab is opened
     if (count() == 1)
     {
         WebView *w = currentWebTab()->view();
-        urlBar()->setUrl(KUrl(""));
-        switch(ReKonfig::newTabsBehaviour())
+        
+        if( currentWebTab()->url().protocol() == QL1S("about") )
+            return;
+        
+        switch (ReKonfig::newTabsBehaviour())
         {
         case 0: // new tab page
         case 1: // blank page
-            w->load( KUrl("about:home") );
+            w->load(KUrl("about:home"));
+            urlBar()->setFocus();
             break;
         case 2: // homepage
-            w->load( KUrl(ReKonfig::homePage()) );
+            w->load(KUrl(ReKonfig::homePage()));
             break;
         default:
             break;
         }
-        urlBar()->setFocus();
         return;
     }
 
@@ -489,50 +484,52 @@ void MainView::closeTab(int index)
     if (index < 0 || index >= count())
         return;
 
-    bool hasFocus = false;
     WebTab *tab = webTab(index);
-    if (tab)
+    if (!tab)
+        return;
+
+    if (tab->view()->isModified())
     {
-        if (tab->view()->isModified())
-        {
-            int risp = KMessageBox::questionYesNo(this,
-                        i18n("This tab contains changes that have not been submitted.\n"
-                             "Closing the tab will discard these changes.\n"
-                             "Do you really want to close this tab?\n"),
-                        i18n("Closing Modified Tab"));
-            if (risp == KMessageBox::No)
-                return;
-        }
-        hasFocus = tab->hasFocus();
-
-        // store close tab except homepage
-        if (!tab->url().prettyUrl().startsWith( QLatin1String("about:") ) && !tab->url().isEmpty())
-        {
-            QString title = tab->view()->title();
-            QString url = tab->url().prettyUrl();
-            HistoryItem item(url, QDateTime::currentDateTime(), title);
-            m_recentlyClosedTabs.removeAll(item);
-            m_recentlyClosedTabs.prepend(item);
-        }
-
-        removeTab(index);
-        updateTabBar();        // UI operation: do it ASAP!!
-        tab->deleteLater();    // tab is scheduled for deletion.
-        
-        emit tabsChanged();
-
-        if (hasFocus && count() > 0)
-        {
-            currentWebTab()->setFocus();
-        }       
+        int risp = KMessageBox::warningContinueCancel(this,
+                   i18n("This tab contains changes that have not been submitted.\n"
+                        "Closing the tab will discard these changes.\n"
+                        "Do you really want to close this tab?\n"),
+                   i18n("Closing Modified Tab"), KGuiItem(i18n("Close &Tab"), "tab-close"), KStandardGuiItem::cancel());
+        if (risp != KMessageBox::Continue)
+            return;
     }
+
+    if (!tab->url().isEmpty())
+    {
+        QString title = tab->view()->title();
+        QString url = tab->url().prettyUrl();
+        HistoryItem item(url, QDateTime(), title);
+        m_recentlyClosedTabs.removeAll(item);
+        m_recentlyClosedTabs.prepend(item);
+    }
+
+    removeTab(index);
+    updateTabBar();        // UI operation: do it ASAP!!
+
+    UrlBar *urlbar = _widgetBar->urlBar(index);
+    _widgetBar->removeWidget(urlbar);
+
+    _widgetBar->setCurrentIndex(m_currentTabIndex);
+
+    if (del)
+    {
+        tab->deleteLater();
+        urlbar->deleteLater();
+    }
+
+    emit tabsChanged();
 }
 
 
 void MainView::webViewLoadStarted()
 {
-    WebView *view = qobject_cast<WebView *>( sender() );
-    int index = indexOf( view->parentWidget() );
+    WebView *view = qobject_cast<WebView *>(sender());
+    int index = indexOf(view->parentWidget());
     if (-1 != index)
     {
         QLabel *label = animatedLoading(index, true);
@@ -546,16 +543,16 @@ void MainView::webViewLoadStarted()
         return;
 
     emit browserTabLoading(true);
-    emit showStatusBarMessage(i18n("Loading..."));
+    emit showStatusBarMessage(i18n("Loading..."), Rekonq::Info);
 }
 
 
 void MainView::webViewLoadFinished(bool ok)
 {
-    WebView *view = qobject_cast<WebView *>( sender() );
+    WebView *view = qobject_cast<WebView *>(sender());
     int index = -1;
-    if(view)
-        index = indexOf( view->parentWidget() );
+    if (view)
+        index = indexOf(view->parentWidget());
 
     if (-1 != index)
     {
@@ -573,18 +570,18 @@ void MainView::webViewLoadFinished(bool ok)
     {
         return;
     }
-    
+
     if (ok)
-        emit showStatusBarMessage(i18n("Done"), Rekonq::Success);
-    else
-        emit showStatusBarMessage(i18n("Failed to load"), Rekonq::Error);
+        emit showStatusBarMessage(i18n("Done"), Rekonq::Info);
+//     else
+//         emit showStatusBarMessage(i18n("Failed to load"), Rekonq::Error);
 }
 
 
 void MainView::webViewIconChanged()
 {
-    WebView *view = qobject_cast<WebView *>( sender() );
-    int index = indexOf( view->parentWidget() );
+    WebView *view = qobject_cast<WebView *>(sender());
+    int index = indexOf(view->parentWidget());
     if (-1 != index)
     {
         KIcon icon = Application::icon(view->url());
@@ -593,28 +590,25 @@ void MainView::webViewIconChanged()
         delete movie;
         label->setMovie(0);
         label->setPixmap(icon.pixmap(16, 16));
-
-        urlBar()->updateUrl();
     }
 }
 
 
 void MainView::webViewTitleChanged(const QString &title)
 {
-    QString tabTitle = title;
-    if (title.isEmpty())
-    {
-        tabTitle = i18n("(Untitled)");
-    }
-    WebView *view = qobject_cast<WebView *>( sender() );
-    int index = indexOf( view->parentWidget() );
+    QString viewTitle = title.isEmpty()? i18n("(Untitled)") : title;
+    QString tabTitle = viewTitle;
+    tabTitle.replace('&', "&&");
+    
+    WebView *view = qobject_cast<WebView *>(sender());
+    int index = indexOf(view->parentWidget());
     if (-1 != index)
     {
         setTabText(index, tabTitle);
     }
     if (currentIndex() == index)
     {
-        emit setCurrentTitle(tabTitle);
+        emit currentTitle(viewTitle);
     }
     Application::historyManager()->updateHistoryEntry(view->url(), tabTitle);
 }
@@ -622,8 +616,8 @@ void MainView::webViewTitleChanged(const QString &title)
 
 void MainView::webViewUrlChanged(const QUrl &url)
 {
-    WebView *view = qobject_cast<WebView *>( sender() );
-    int index = indexOf( view->parentWidget() );
+    WebView *view = qobject_cast<WebView *>(sender());
+    int index = indexOf(view->parentWidget());
     if (-1 != index)
     {
         tabBar()->setTabData(index, url);
@@ -649,6 +643,39 @@ void MainView::previousTab()
     setCurrentIndex(next);
 }
 
+void MainView::openClosedTabs()
+{
+    foreach (const HistoryItem &item, recentlyClosedTabs())
+    {
+        Application::instance()->loadUrl( KUrl(item.url), Rekonq::NewTab);
+    }
+    m_recentlyClosedTabs.clear();
+}
+
+void MainView::openClosedTab()
+{
+    KAction *action = qobject_cast<KAction *>(sender());
+    if (action)
+    {
+        Application::instance()->loadUrl(action->data().toUrl(), Rekonq::NewTab);
+        
+        QString title = action->text();
+        title = title.remove('&');
+        HistoryItem item(action->data().toString(), QDateTime(), title );
+        m_recentlyClosedTabs.removeAll(item);
+    }
+}
+
+void MainView::switchToTab()
+{
+    // uses the sender to determine the tab index
+    QAction *sender = static_cast<QAction*>(QObject::sender());
+    int index = sender->data().toInt();
+    index -= 1; // to compensate for off by 1 presented to the user
+    if( index < 0 || index >= count() )
+        return;
+    setCurrentIndex( index );
+}
 
 QLabel *MainView::animatedLoading(int index, bool addMovie)
 {
@@ -673,12 +700,6 @@ QLabel *MainView::animatedLoading(int index, bool addMovie)
 }
 
 
-QList<HistoryItem> MainView::recentlyClosedTabs()
-{
-    return m_recentlyClosedTabs;
-}
-
-
 void MainView::resizeEvent(QResizeEvent *event)
 {
     updateTabBar();
@@ -693,8 +714,23 @@ void MainView::detachTab(int index)
     if (index < 0 || index >= count())
         return;
 
-    KUrl url = webTab(index)->view()->url();
-    closeTab(index);
-    
-    Application::instance()->loadUrl(url, Rekonq::NewWindow);
+    WebTab *tab = webTab(index);
+    KUrl u = tab->url();
+    kDebug() << "detaching tab with url: " << u;
+    if (u.scheme() == QL1S("about"))
+    {
+        closeTab(index);
+        Application::instance()->loadUrl(u, Rekonq::NewWindow);
+    }
+    else
+    {
+        QString label = tab->view()->title();
+        UrlBar *bar = _widgetBar->urlBar(index);
+        closeTab(index, false);
+
+        MainWindow *w = Application::instance()->newMainWindow(false);
+        w->mainView()->addTab(tab, Application::icon(u), label);
+        w->mainView()->widgetBar()->insertWidget(0, bar);
+        w->mainView()->updateTabBar();
+    }
 }
