@@ -13,9 +13,9 @@
 * published by the Free Software Foundation; either version 2 of
 * the License or (at your option) version 3 or any later version
 * accepted by the membership of KDE e.V. (or its successor approved
-* by the membership of KDE e.V.), which shall act as a proxy 
+* by the membership of KDE e.V.), which shall act as a proxy
 * defined in Section 14 of version 3 of the license.
-* 
+*
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
@@ -31,13 +31,17 @@
 #define MAINVIEW_H
 
 
+// Rekonq Includes
+#include "rekonq_defines.h"
+
 // Local Includes
-#include "rekonqprivate_export.h"
 #include "webview.h"
 #include "webpage.h"
+#include "webtab.h"
 #include "application.h"
 #include "historymanager.h"
 #include "mainwindow.h"
+#include "stackedurlbar.h"
 
 // KDE Includes
 #include <KTabWidget>
@@ -56,7 +60,7 @@ class UrlBar;
 
 
 /**
- * This class represent rekonq Main View. 
+ * This class represent rekonq Main View.
  * It contains all WebViews and the url bar.
  *
  */
@@ -69,6 +73,7 @@ public:
     MainView(MainWindow *parent);
     ~MainView();
 
+    inline StackedUrlBar *widgetBar() const { return _widgetBar; }
     UrlBar *urlBar() const;
     WebTab *webTab(int index) const;
 
@@ -81,23 +86,21 @@ public:
      *
      */
     void updateTabBar();
-    
+
     void setTabBarHidden(bool hide);
-    
-    QToolButton *addTabButton() const;
-    void clear();
+
+    inline QToolButton *addTabButton() const { return m_addTabButton; }
 
     /**
      * This function creates a new empty tab
      * with a webview inside
-     * @param focused   decide if you wannna give focus 
+     * @param focused   decide if you wannna give focus
      *                  (or not) to this new tab (default true)
-     * @param nearParent  decide if you wanna create new tab near current or not
      * @return the webview embedded in the new tab
      */
-    WebTab *newWebTab(bool focused = true, bool nearParent = false);
+    WebTab *newWebTab(bool focused = true);
 
-    QList<HistoryItem> recentlyClosedTabs();
+    inline QList<HistoryItem> recentlyClosedTabs() { return m_recentlyClosedTabs; }
 
 signals:
     // tab widget signals
@@ -105,7 +108,7 @@ signals:
     void lastTabClosed();
 
     // current tab signals
-    void setCurrentTitle(const QString &url);
+    void currentTitle(const QString &url);
     void showStatusBarMessage(const QString &message, Rekonq::Notify status = Rekonq::Info);
     void linkHovered(const QString &link);
     void browserTabLoading(bool);
@@ -121,15 +124,21 @@ public slots:
      */
     void newTab();
 
+    // Indexed slots
     void cloneTab(int index = -1);
-    void closeTab(int index = -1);
-    void closeOtherTabs(int index);
+    void closeTab(int index = -1, bool del = true);
+    void closeOtherTabs(int index = -1);
     void reloadTab(int index = -1);
+    void detachTab(int index = -1);
+    
     void reloadAllTabs();
     void nextTab();
     void previousTab();
-    void detachTab(int index = -1);
     
+    void openClosedTabs();
+    void openClosedTab();
+    void switchToTab();
+
     // WEB slot actions
     void webReload();
     void webStop();
@@ -147,7 +156,6 @@ private slots:
 
     void postLaunch();
 
-
 protected:
     virtual void resizeEvent(QResizeEvent *event);
 
@@ -169,7 +177,7 @@ private:
 
 // --------------------------------------------------------------------------
 
-    UrlBar *m_urlBar;
+    StackedUrlBar *_widgetBar;
 
     QString m_loadingGitPath;
 
