@@ -31,11 +31,8 @@
 #ifndef MAINWINDOW_H
 #define MAINWINDOW_H
 
-
-// Local Includes
-#include "rekonqprivate_export.h"
-#include "application.h"
-#include "previewselectorbar.h"
+// Rekonq Includes
+#include "rekonq_defines.h"
 
 // KDE Includes
 #include <KMainWindow>
@@ -44,18 +41,19 @@
 #include <KUrl>
 
 // Forward Declarations
-class QWebFrame;
-class QSlider;
-
-class KAction;
-class KPassivePopup;
-
 class FindBar;
 class HistoryPanel;
 class BookmarksPanel;
 class WebInspectorPanel;
 class WebTab;
 class MainView;
+class NetworkAnalyzerPanel;
+
+class KAction;
+class KPassivePopup;
+
+class QWebFrame;
+class QSlider;
 
 
 /**
@@ -71,23 +69,22 @@ public:
     MainWindow();
     ~MainWindow();
 
-    MainView *mainView() const;
+    inline MainView *mainView() const { return m_view; }
+    inline KActionCollection *actionCollection() const { return m_ac; }
+    inline QAction *actionByName(const QString &name) { return actionCollection()->action(name); }
+    
     WebTab *currentTab() const;
-    QAction *actionByName(const QString name);
     virtual QSize sizeHint() const;
-    virtual KActionCollection *actionCollection () const;
     void setWidgetsVisible(bool makeFullScreen);
 
-    void setZoomSliderFactor(qreal factor);
-
 private:
     void setupActions();
     void setupTools();
     void setupToolbars();
     void setupPanels();
-    
+
 public slots:
-    void homePage();
+    void homePage(Qt::MouseButtons = Qt::LeftButton, Qt::KeyboardModifiers = Qt::NoModifier);
 
     /**
      * Notifies a message in a popup
@@ -97,10 +94,14 @@ public slots:
      * @param status The status message
      *
      */
-    void notifyMessage(const QString &msg, Rekonq::Notify status = Rekonq::Info);
+    void notifyMessage(const QString &msg, Rekonq::Notify status = Rekonq::Url);
 
     void printRequested(QWebFrame *frame = 0);
-    
+
+    void updateActions();
+
+    void setZoomSliderFactor(qreal factor);
+
 signals:
     // switching tabs
     void ctrlTabPressed();
@@ -114,22 +115,23 @@ protected:
     */
     void keyPressEvent(QKeyEvent *event);
 
+    bool queryClose();
+    
 private slots:
     void postLaunch();
-    void updateConfiguration();
     void browserLoading(bool);
-    void updateActions();
     void updateWindowTitle(const QString &title = QString());
 
     // history related
-    void openPrevious();
-    void openNext();
+    void openPrevious(Qt::MouseButtons = Qt::LeftButton, Qt::KeyboardModifiers = Qt::NoModifier);
+    void openNext(Qt::MouseButtons = Qt::LeftButton, Qt::KeyboardModifiers = Qt::NoModifier);
 
     // Find Action slots
     void find(const QString &);
     void matchCaseUpdate();
     void findNext();
     void findPrevious();
+    void highlightAll();
 
     // Zoom slots
     void zoomIn();
@@ -157,6 +159,12 @@ private slots:
     void aboutToShowBackMenu();
     void openActionUrl(QAction *action);
 
+    // encodings
+    void setEncoding(QAction *);
+    void populateEncodingMenu();
+
+    void enableNetworkAnalysis(bool);
+    
 private:
     MainView *m_view;
     FindBar *m_findBar;
@@ -164,9 +172,11 @@ private:
     HistoryPanel *m_historyPanel;
     BookmarksPanel *m_bookmarksPanel;
     WebInspectorPanel *m_webInspectorPanel;
-
+    NetworkAnalyzerPanel *m_analyzerPanel;
+    
     KAction *m_stopReloadAction;
     KMenu *m_historyBackMenu;
+    KMenu *m_encodingMenu;
 
     KToolBar *m_mainBar;
     KToolBar *m_bmBar;
