@@ -11,9 +11,9 @@
 * published by the Free Software Foundation; either version 2 of
 * the License or (at your option) version 3 or any later version
 * accepted by the membership of KDE e.V. (or its successor approved
-* by the membership of KDE e.V.), which shall act as a proxy 
+* by the membership of KDE e.V.), which shall act as a proxy
 * defined in Section 14 of version 3 of the license.
-* 
+*
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
@@ -29,8 +29,11 @@
 #define NETWORKACCESSMANAGER_H
 
 
+// Rekonq Includes
+#include "rekonq_defines.h"
+
 // Local Includes
-#include "rekonqprivate_export.h"
+#include "webpage.h"
 
 // KDE Includes
 #include <kio/accessmanager.h>
@@ -44,10 +47,16 @@ class REKONQ_TESTS_EXPORT NetworkAccessManager : public AccessManager
     Q_OBJECT
 
 public:
-    NetworkAccessManager(QObject *parent = 0);
+    NetworkAccessManager(QObject *parent);
 
 protected:
-    virtual QNetworkReply *createRequest(Operation op, const QNetworkRequest &req, QIODevice *outgoingData = 0);
+    virtual QNetworkReply *createRequest(QNetworkAccessManager::Operation op, const QNetworkRequest &request, QIODevice *outgoingData = 0);
+
+signals:
+    void networkData(QNetworkAccessManager::Operation op, const QNetworkRequest &request, QNetworkReply *reply); 
+
+private:
+    QByteArray _acceptLanguage;
 };
 
 #endif // NETWORKACCESSMANAGER_H
