@@ -35,19 +35,20 @@
 #include "mainwindow.h"
 #include "mainview.h"
 #include "webtab.h"
+#include "tabbar.h"
 
 // KDE Includes
 #include <KStandardDirs>
-#include <KDebug>
 
 // Qt Includes
-#include <QFile>
-#include <QTextStream>
+#include <QtCore/QFile>
+#include <QtCore/QTextStream>
+
 
 
 SessionManager::SessionManager(QObject *parent)
-    : QObject(parent)
-    , m_safe(true)
+        : QObject(parent)
+        , m_safe(true)
 {
     m_sessionFilePath = KStandardDirs::locateLocal("appdata" , "session");
 }
@@ -60,7 +61,7 @@ SessionManager::~SessionManager()
 
 void SessionManager::saveSession()
 {
-    if(!m_safe)
+    if (!m_safe)
         return;
     m_safe = false;
     QFile sessionFile(m_sessionFilePath);
@@ -71,7 +72,7 @@ void SessionManager::saveSession()
     }
     QTextStream out(&sessionFile);
     MainWindowList wl = Application::instance()->mainWindowList();
-    Q_FOREACH(QWeakPointer<MainWindow> w, wl)
+    Q_FOREACH(const QWeakPointer<MainWindow> &w, wl)
     {
         out << "window\n";
         MainView *mv = w.data()->mainView();
@@ -79,6 +80,10 @@ void SessionManager::saveSession()
         {
             out << mv->webTab(i)->url().toEncoded() << "\n";
         }
+        
+        // Current Tab for window
+        out << "currenttab\n";
+        out << mv->tabBar()->currentIndex() << "\n";
     }
     sessionFile.close();
     m_safe = true;
@@ -102,19 +107,72 @@ bool SessionManager::restoreSession()
     do
     {
         line = in.readLine();
-        if(line == QString("window"))
+        if (line == QL1S("window"))
         {
             line = in.readLine();
-            kDebug() << "New Window line: " << line;
-            Application::instance()->loadUrl(line, Rekonq::NewWindow);
+            Application::instance()->loadUrl( KUrl(line), Rekonq::NewWindow);
         }
         else
         {
-            kDebug() << "New Current Tab line: " << line;
-            Application::instance()->loadUrl(line, Rekonq::NewCurrentTab);
+            if (line == QL1S("currenttab"))
+            {
+                line = in.readLine();
+                bool ok;
+                int idx = line.toInt(&ok);
+                if (ok)
+                {
+                    // Get last mainwindow created which will be first one in mainwindow list
+                    MainWindowList wl = Application::instance()->mainWindowList();
+                    if (wl.count() > 0)
+                    {
+                        MainView *mv = wl[0].data()->mainView();
+                        emit mv->tabBar()->setCurrentIndex(idx);
+                    }
+                }
+            }
+            else
+            {
+                Application::instance()->loadUrl( KUrl(line), Rekonq::NewFocusedTab);
+            }
         }
     }
-    while(!line.isEmpty());
-    
+    while (!line.isEmpty());
+
     return true;
 }
+
+
+QStringList SessionManager::closedSites()
+{
+    QStringList list;
+    
+    QFile sessionFile(m_sessionFilePath);
+    if (!sessionFile.exists())
+        return list;
+    if (!sessionFile.open(QFile::ReadOnly))
+    {
+        kDebug() << "Unable to open session file" << sessionFile.fileName();
+        return list;
+    }
+
+    QTextStream in(&sessionFile);
+    QString line;
+    do
+    {
+        line = in.readLine();
+        if (line != QL1S("window"))
+        {
+            if(line == QL1S("currenttab"))
+            {
+                in.readLine();  // drop out the next field, containing the index of the current tab..
+            }
+            else
+            {
+                list << QString(line);
+            }
+        }
+    }
+    while (!line.isEmpty());
+
+    return list;
+}
