@@ -11,9 +11,9 @@
 * published by the Free Software Foundation; either version 2 of
 * the License or (at your option) version 3 or any later version
 * accepted by the membership of KDE e.V. (or its successor approved
-* by the membership of KDE e.V.), which shall act as a proxy 
+* by the membership of KDE e.V.), which shall act as a proxy
 * defined in Section 14 of version 3 of the license.
-* 
+*
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
@@ -29,8 +29,8 @@
 #define SETTINGS_DIALOG_H
 
 
-// Local Includes
-#include "rekonqprivate_export.h"
+// Rekonq Includes
+#include "rekonq_defines.h"
 
 // KDE Includes
 #include <KConfigDialog>
@@ -47,18 +47,15 @@ class REKONQ_TESTS_EXPORT SettingsDialog : public KConfigDialog
 public:
     SettingsDialog(QWidget *parent = 0);
     ~SettingsDialog();
-    
+
     virtual bool hasChanged();
 
 private:
     Private* const d;
-    void setWebSettingsToolTips();
 
 private slots:
     void readConfig();
     void saveSettings();
-
-    void setHomeToCurrentPage();
 };
 
 #endif // SETTINGS_DIALOG_H
