@@ -11,9 +11,9 @@
 * published by the Free Software Foundation; either version 2 of
 * the License or (at your option) version 3 or any later version
 * accepted by the membership of KDE e.V. (or its successor approved
-* by the membership of KDE e.V.), which shall act as a proxy 
+* by the membership of KDE e.V.), which shall act as a proxy
 * defined in Section 14 of version 3 of the license.
-* 
+*
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
@@ -29,8 +29,8 @@
 #define WEB_PLUGIN_FACTORY_H
 
 
-// Local Includes
-#include "rekonqprivate_export.h"
+// Rekonq Includes
+#include "rekonq_defines.h"
 
 // KDE Includes
 #include <KWebPluginFactory>
@@ -42,11 +42,10 @@
 
 class REKONQ_TESTS_EXPORT WebPluginFactory : public KWebPluginFactory
 {
-Q_OBJECT
+    Q_OBJECT
 
 public:
     WebPluginFactory(QObject *parent);
-    ~WebPluginFactory();
 
     virtual QObject *create(const QString &mimeType,
                             const QUrl &url,
@@ -55,10 +54,10 @@ public:
 
 signals:
     void signalLoadClickToFlash(bool) const;
-    
+
 public slots:
     void setLoadClickToFlash(bool load);
-    
+
 private:
     /**
         When true, force loading of next flash animation (don't show clicktoflash)
