@@ -11,9 +11,9 @@
 * published by the Free Software Foundation; either version 2 of
 * the License or (at your option) version 3 or any later version
 * accepted by the membership of KDE e.V. (or its successor approved
-* by the membership of KDE e.V.), which shall act as a proxy 
+* by the membership of KDE e.V.), which shall act as a proxy
 * defined in Section 14 of version 3 of the license.
-* 
+*
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
@@ -29,8 +29,12 @@
 #define WEBTAB_H
 
 
+// Rekonq Includes
+#include "rekonq_defines.h"
+
 // Local Includes
-#include "rekonqprivate_export.h"
+#include "webpage.h"
+#include "webview.h"
 
 // KDE Includes
 #include <KUrl>
@@ -38,10 +42,6 @@
 // Qt Includes
 #include <QWidget>
 
-// Forward Declarations
-class WebPage;
-class WebView;
-
 
 class REKONQ_TESTS_EXPORT WebTab : public QWidget
 {
@@ -51,20 +51,28 @@ public:
     explicit WebTab(QWidget *parent = 0);
     ~WebTab();
 
-    WebView *view();
-    WebPage *page();
-    KUrl url();
-
-    int progress();
-    void createPreviewSelectorBar(int index);
+    inline WebView *view() { return _view; }
+    inline WebPage *page() { return view()->page(); }
+    inline int progress() { return m_progress; }
     
+    KUrl url();
+    void createPreviewSelectorBar(int index);
+
+    bool hasRSSInfo();
+
 private slots:
     void updateProgress(int progress);
     void loadFinished(bool);
 
     void createWalletBar(const QString &, const QUrl &);
+    void showRSSInfo(QPoint pos);
 
+signals:
+    void loadProgressing();
+    
 private:
+    WebView *_view;
+    
     int m_progress;
 };
 
