@@ -11,9 +11,9 @@
 * published by the Free Software Foundation; either version 2 of
 * the License or (at your option) version 3 or any later version
 * accepted by the membership of KDE e.V. (or its successor approved
-* by the membership of KDE e.V.), which shall act as a proxy 
+* by the membership of KDE e.V.), which shall act as a proxy
 * defined in Section 14 of version 3 of the license.
-* 
+*
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
@@ -28,11 +28,9 @@
 #ifndef WEBVIEW_H
 #define WEBVIEW_H
 
-// Local Includes
-#include "rekonqprivate_export.h"
 
-// Local Includes
-#include "application.h"
+// Rekonq Includes
+#include "rekonq_defines.h"
 
 // KDE Includes
 #include <KWebView>
@@ -50,13 +48,15 @@ public:
     ~WebView();
 
     WebPage *page();
-    QPoint mousePos();
+    
+    inline QPoint mousePos() { return _mousePos; }
 
 protected:
     void contextMenuEvent(QContextMenuEvent *event);
-    void mousePressEvent(QMouseEvent *event);// need to be ported
+    void mousePressEvent(QMouseEvent *event);
     void mouseMoveEvent(QMouseEvent *event);
     void keyPressEvent(QKeyEvent *event);
+    void wheelEvent(QWheelEvent *event);
 
 private slots:
     void search();
@@ -66,15 +66,25 @@ private slots:
     void loadUrlInNewTab(const KUrl &);
     void openLinkInNewWindow();
     void openLinkInNewTab();
-    
+
     void viewImage(Qt::MouseButtons buttons, Qt::KeyboardModifiers modifiers);
     void inspect();
 
+    void scrollFrameChanged();
+
 signals:
     void loadUrl(const KUrl &, const Rekonq::OpenType &);
-    
+    void zoomChanged(qreal);
+
 private:
-    QPoint m_mousePos;
+    QPoint _mousePos;
+    QPoint _clickPos;
+
+    QTimer *_scrollTimer;
+    int _VScrollSpeed;
+    int _HScrollSpeed;
+    bool _canEnableAutoScroll;
+    bool _isAutoScrollEnabled;
 };
 
 #endif
